@@ -238,33 +238,25 @@ class NamesUrlsMixin(Model):
 
     def get_update_url(self) -> str:
         try:
-            return reverse(
-                f'{self.get_url_base_name}_update', kwargs={'pk': self.pk}
-            )
+            return reverse(f'{self.get_url_base_name}_update', kwargs={'pk': self.pk})
         except NoReverseMatch:
             return '#'
 
     def get_clone_url(self) -> str:
         try:
-            return reverse(
-                f'{self.get_url_base_name}_clone', kwargs={'pk': self.pk}
-            )
+            return reverse(f'{self.get_url_base_name}_clone', kwargs={'pk': self.pk})
         except NoReverseMatch:
             return '#'
 
     def get_delete_url(self) -> str:
         try:
-            return reverse(
-                f'{self.get_url_base_name}_delete', kwargs={'pk': self.pk}
-            )
+            return reverse(f'{self.get_url_base_name}_delete', kwargs={'pk': self.pk})
         except NoReverseMatch:
             return '#'
 
     def get_toggle_url(self) -> str:
         try:
-            return reverse(
-                f'{self.get_url_base_name}_toggle', kwargs={'pk': self.pk}
-            )
+            return reverse(f'{self.get_url_base_name}_toggle', kwargs={'pk': self.pk})
         except NoReverseMatch:
             return '#'
 
