@@ -263,10 +263,11 @@ class PrefillForm(ScrubbedGetParams):
     # -----------------------------------------------------
     def get_form(self, data: Any = None, files: Any = None, **kwargs: Any) -> ModelForm:
         initial = kwargs.pop('initial', {})
-        initial.update({field: val for field, val in self.scrubbed_get_params().items()})
+        initial |= {field: val for field, val in self.scrubbed_get_params().items()}
 
         # initial values defined from URL / View should override other initial values
-        initial.update(self.kwargs.get('initial', {}))
+        if view_kwargs := self.kwargs:
+            initial |= view_kwargs
         kwargs['initial'] = initial
 
         return super().get_form(data=data, files=files, **kwargs)
@@ -680,11 +681,11 @@ class ObjectURLs(CrumbTrail):
 
     # -----------------------------------------------------
     def get_form(self, data: Any = None, files: Any = None, **kwargs: Any) -> ModelForm:
-        kwargs.update({
+        kwargs |= {
             'user': self.request.user,
             settings.CLONING_RECORD_KEY: self.cloning_existing_record(),
             settings.UNIVERSAL_RECORD_KEY: self.record_is_universal(),
-        })
+        }
 
         return super().get_form(data=data, files=files, **kwargs)
 
